/************************************************************ 

Data set and Replication command syntax file for:

           Representation and Policy Responsiveness
				
                              Bing and Shin-Goo, Feb.12,2010

*************************************************************/

/* Upload Data set for Analysis */
use "C:\0.1.ShinGooKang\MyPapers\Median+Welfare\2010JOP_DataReplication\dt1002.dta", clear


/******************************
For Figure 1 and Figure 2, the variables of interest are: 
avttnzr3 avsmttnzr3 avprttnzr3
avvidr3 avsmvidr3 avprvidr3
*******************************/

/* Creating Figure 1, Panel A */ 
#delimit;
twoway (connected avttnzr3 year if us==1, connect(L) lcolor(blue) msymbol(circle)) 
	(connected avsmttnzr3 year if us==1, connect(L) lcolor(red) msymbol(x))
	(connected avprttnzr3 year if ger==1, connect(L) lcolor(red) msymbol(square)), 
	title(Redistributive Welfare Spending by Electoral System) 
	note(PR systems are represented by squre and SMD systems by X marker) 
	legend(off);
#delimit cr

/* Creating Figure 1, Panel B */
#delimit;
twoway (connected avvidr3 year if us==1, connect(L) lcolor(blue) msymbol(circle)) 
	(connected avsmvidr3 year if us==1, connect(L) lcolor(red) msymbol(x))
	(connected avprvidr3 year if ger==1, connect(L) lcolor(red) msymbol(square)), 
	title(Median Voter Ideological Position by Electoral System) 
	note(PR systems are represented by squre and SMD systems by X marker) 
	legend(off);
#delimit cr 

	/*For the paper, we used R to draw the figure 
	since R is easier to edit the figures.
	However, the results are exactly identical 
	The R command syntax is attached in a separate file.*/

/* Table 1 Model 1 */
#delimit ;
xtpcse dttnz 
	ttnz1 due ue1 dpop65 pop651 dcpi cpi1 ddy dy1 y2 
	open1 ctax1 itax1 ttax1 uden1
	dele ele1 dhr hr1 sdrw1 vp1 vp1rw1 rw1 dttnz1 
	dttnz17a
	ger fra ita uk can aus bel den fin
	ire net nor	swe swi aur	nz, pairwise;
#delimit cr

	/* To get adjusted R-square,
	replace xtpcse with reg and delete (, pairwise) option */

/* Table 1 Model 2 */
#delimit ;
xtpcse dttnz 
	ttnz1 
	dvidnewf vidnewf1 pocatholic 
	due ue1 dpop65 pop651 dcpi cpi1 ddy dy1 y2 
	open1 ctax1 itax1 ttax1 uden1 
	dele ele1 dhr hr1 sdrw1 vp1 vp1rw1 rw1 dttnz1
	dttnz17a
	ger fra ita uk can aus bel den fin
	ire net nor	swe swi aur	nz, pairwise;
#delimit cr
nlcom -_b[vidnewf1]/_b[ttnz1]

       /*The above command line is to get the coefficient and standard error 
       for the long-term equilibrium effect */ 

/* Table 1 Model 3 */
#delimit ;
xtpcse dttnz 
	ttnz1 
	dvidnewf vidnewf1 pocatholic
	due ue1 dpop65 pop651 dcpi cpi1 ddy dy1 y2 
	open1 ctax1 itax1 ttax1 uden1 
	dele ele1 dhr hr1 sdrw1 vp1 vp1rw1 rw1 dttnz1
	dttnz17a
	fra bel net, pairwise;
#delimit cr
nlcom -_b[vidnewf1]/_b[ttnz1]

/* Table 2 Model 4 */
#delimit ;
xtpcse dttnz 
	ttnz1  
	dgidnewf gidnewf1 
	pocatholic
	due ue1 dpop65 pop651 dcpi cpi1 ddy dy1 y2 
	open1 ctax1 itax1 ttax1 uden1 dele ele1
	dhr hr1 sdrw1 vp1 vp1rw1 rw1 
	dttnz1 dttnz17a
	fra bel net, pairwise;
#delimit cr
nlcom -_b[gidnewf1]/_b[ttnz1]

/* Table 2 Model 5 */
#delimit ;
xtpcse dttnz 
	ttnz1  
	dvidnewf vidnewf1 dgidnewf gidnewf1 
	pocatholic
	due ue1 dpop65 pop651 dcpi cpi1 ddy dy1 y2 
	open1 ctax1 itax1 ttax1 uden1 dele ele1
	dhr hr1 sdrw1 vp1 vp1rw1 rw1 
	dttnz1 dttnz17a
	fra bel net, pairwise;
#delimit cr
nlcom -_b[vidnewf1]/_b[ttnz1]
nlcom -_b[gidnewf1]/_b[ttnz1]

/* Table 3 Model 6 */
#delimit ;
xtpcse dttnz 
	ttnz1
	dvidnewf prfdvid vidnewf1 prfvid1 
	prf pocatholic 
	due ue1 dpop65 pop651 dcpi cpi1 ddy dy1 y2 
	open1 ctax1 itax1 ttax1 uden1  dele ele1
	dhr hr1 sdrw1 vp1 vp1rw1 rw1  
	dttnz1 dttnz17a
	ger fra ita uk can aus bel den fin
	ire net nor	swe swi aur	nz, pairwise;
#delimit cr

lincom _cons+prf 
lincom dvidnewf+prfdvid
nlcom -_b[vidnewf1]/_b[ttnz1]
nlcom -(_b[vidnewf1]+_b[prfvid1])/_b[ttnz1]

/* Table 3 Model 7 */
#delimit ;
xtpcse dttnz 
	ttnz1 
	dvidnewf prfdvid vidnewf1 prfvid1 
	prf pocatholic
	due ue1 dpop65 pop651 dcpi cpi1 ddy dy1 y2 
	open1 ctax1 itax1 ttax1 uden1 dele ele1
	dhr hr1 sdrw1 vp1 vp1rw1 rw1
	dttnz1 dttnz17a
	fra bel net, pairwise;
#delimit cr

lincom _cons+prf 
lincom dvidnewf+prfdvid
nlcom -_b[vidnewf1]/_b[ttnz1]
nlcom -(_b[vidnewf1]+_b[prfvid1])/_b[ttnz1]

/* Table 3 Model 8 */
#delimit ;
xtpcse dttnz 
	ttnz1 
	dvidnewf prfdvid vidnewf1 prfvid1 
	dgidnewf prfdgid gidnewf1 prfgid1 
	prf pocatholic
	due ue1 dpop65 pop651 dcpi cpi1 ddy dy1 y2 
	open1 ctax1 itax1 ttax1 uden1 dele ele1
	dhr hr1 sdrw1 vp1 vp1rw1 rw1
	dttnz1  dttnz17a
	fra bel net, pairwise;
#delimit cr

lincom _cons+prf 
lincom dvidnewf+prfdvid
lincom dgidnewf+prfdgid
nlcom -_b[vidnewf1]/_b[ttnz1]
nlcom -(_b[vidnewf1]+_b[prfvid1])/_b[ttnz1]
nlcom -_b[gidnewf1]/_b[ttnz1]
nlcom -(_b[gidnewf1]+_b[prfgid1])/_b[ttnz1]

/* Table 3 Model 9 */
#delimit ;
xtfevd dttnz 
	ttnz1 
	prf pocatholic
	due ue1 dpop65 pop651 dcpi cpi1 ddy dy1 y2 
	open1 ctax1 itax1 ttax1 uden1 dele ele1
	dhr hr1 sdrw1 vp1 vp1rw1 rw1 
	dttnz1 dttnz17a,
	invariant(prf pocatholic);
#delimit cr
nlcom -_b[prf]/_b[ttnz1]
nlcom -_b[pocatholic]/_b[ttnz1]

       /*If you are seeing 'unrecognized command,'
         you need to install xtfevd (Pluemper and Troeger 2007) 
         in order to run this model specification.
         We get the ado file from Pluemper (tpluem@essex.ac.uk ).*/    

/* Table 3 Model 10 */
#delimit ;
xtfevd dttnz 
	ttnz1 
	prf pocatholic
	dvidnewf vidnewf1
	due ue1 dpop65 pop651 dcpi cpi1 ddy dy1 y2 
	open1 ctax1 itax1 ttax1 uden1 dele ele1 
	dhr hr1 sdrw1 vp1 vp1rw1 rw1 dttnz1 dttnz17a,
	invariant(prf pocatholic);
#delimit cr
nlcom -_b[prf]/_b[ttnz1]
nlcom -_b[pocatholic]/_b[ttnz1]
nlcom -_b[vidnewf1]/_b[ttnz1]

